VideoMixer.FrameSpec (video_mixer v2.1.5)

Summary

Functions

Returns true if frame is compatible with the provided specification.

Types

fit_mode()

@type fit_mode() :: :crop | :fit

t()

@type t() :: %VideoMixer.FrameSpec{
  accepted_frame_size: integer(),
  fit_mode: fit_mode(),
  height: pos_integer(),
  pixel_format: atom(),
  reference: any(),
  width: pos_integer()
}

Functions

compatible?(arg1, frame)

@spec compatible?(t(), VideoMixer.Frame.t()) :: boolean()

Returns true if frame is compatible with the provided specification.